@@ -142,13 +142,18 @@ class TriggerTree(CausalTreeLearn):
                 return return_val
             train_err = train_effect ** 2
 
-            train_mse = (1 - self.weight) * (total_train * train_err)
-            cost = self.weight * total_val * np.abs(train_effect - val_effect)
-            # print(train_mse, cost, total_train, total_val, np.abs(total_train - total_val) + 1)
-            obj = (train_mse - cost) / (np.abs(total_train - total_val) + 1)
+            # train_mse = (1 - self.weight) * (total_train * train_err)
+            # cost = self.weight * total_val * np.abs(train_effect - val_effect)
+            # # print(train_mse, cost, total_train, total_val, np.abs(total_train - total_val) + 1)
+            # obj = (train_mse - cost) / (np.abs(total_train - total_val) + 1)
+
+            train_mse = (1 - self.weight) * (train_effect ** 2)
+            cost = self.weight * np.abs(train_effect - val_effect)
+            obj = train_mse - cost
 
             best_obj = obj
-            best_mse = train_err
+            # best_mse = train_err
+            best_mse = total_train * train_err
 
             return best_obj, best_trigger, best_mse
 
